@@ -24,4 +24,8 @@ class EntryForm(CustomForm, forms.ModelForm):
 class CategoryForm(CustomForm, forms.ModelForm):
     class Meta:
         model = models.Category
-        fields = '__all__'
\ No newline at end of file
+        fields = '__all__'
+        widgets ={
+            'name':genwidgets.TextInput
+        }
+
